@@ -91,7 +91,7 @@ class Border(object):
     def link(self):
         """Gets the link of this Border.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :return: The link of this Border.  # noqa: E501
         :rtype: WordsApiLink
@@ -102,7 +102,7 @@ class Border(object):
     def link(self, link):
         """Sets the link of this Border.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :param link: The link of this Border.  # noqa: E501
         :type: WordsApiLink
@@ -141,7 +141,7 @@ class Border(object):
     def color(self):
         """Gets the color of this Border.  # noqa: E501
 
-        Gets or sets the border color.               # noqa: E501
+        Gets or sets color.  # noqa: E501
 
         :return: The color of this Border.  # noqa: E501
         :rtype: XmlColor
@@ -152,7 +152,7 @@ class Border(object):
     def color(self, color):
         """Sets the color of this Border.
 
-        Gets or sets the border color.               # noqa: E501
+        Gets or sets color.  # noqa: E501
 
         :param color: The color of this Border.  # noqa: E501
         :type: XmlColor
