@@ -49,6 +49,8 @@ class DocSaveOptionsData(object):
         'update_last_saved_time_property': 'bool',
         'update_sdt_content': 'bool',
         'update_fields': 'bool',
+        'dml3_d_effects_rendering_mode': 'str',
+        'update_last_printed_property': 'bool',
         'always_compress_metafiles': 'bool',
         'password': 'str',
         'save_picture_bullet': 'bool',
@@ -64,13 +66,15 @@ class DocSaveOptionsData(object):
         'update_last_saved_time_property': 'UpdateLastSavedTimeProperty',
         'update_sdt_content': 'UpdateSdtContent',
         'update_fields': 'UpdateFields',
+        'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
+        'update_last_printed_property': 'UpdateLastPrintedProperty',
         'always_compress_metafiles': 'AlwaysCompressMetafiles',
         'password': 'Password',
         'save_picture_bullet': 'SavePictureBullet',
         'save_routing_slip': 'SaveRoutingSlip'
     }
 
-    def __init__(self, save_format=None, file_name=None, dml_rendering_mode=None, dml_effects_rendering_mode=None, zip_output=None, update_last_saved_time_property=None, update_sdt_content=None, update_fields=None, always_compress_metafiles=None, password=None, save_picture_bullet=None, save_routing_slip=None):  # noqa: E501
+    def __init__(self, save_format=None, file_name=None, dml_rendering_mode=None, dml_effects_rendering_mode=None, zip_output=None, update_last_saved_time_property=None, update_sdt_content=None, update_fields=None, dml3_d_effects_rendering_mode=None, update_last_printed_property=None, always_compress_metafiles=None, password=None, save_picture_bullet=None, save_routing_slip=None):  # noqa: E501
         """DocSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
         self._save_format = None
@@ -81,6 +85,8 @@ class DocSaveOptionsData(object):
         self._update_last_saved_time_property = None
         self._update_sdt_content = None
         self._update_fields = None
+        self._dml3_d_effects_rendering_mode = None
+        self._update_last_printed_property = None
         self._always_compress_metafiles = None
         self._password = None
         self._save_picture_bullet = None
@@ -103,6 +109,10 @@ class DocSaveOptionsData(object):
             self.update_sdt_content = update_sdt_content
         if update_fields is not None:
             self.update_fields = update_fields
+        if dml3_d_effects_rendering_mode is not None:
+            self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
+        if update_last_printed_property is not None:
+            self.update_last_printed_property = update_last_printed_property
         if always_compress_metafiles is not None:
             self.always_compress_metafiles = always_compress_metafiles
         if password is not None:
@@ -281,6 +291,56 @@ class DocSaveOptionsData(object):
         """
         self._update_fields = update_fields
     @property
+    def dml3_d_effects_rendering_mode(self):
+        """Gets the dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :return: The dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :rtype: str
+        """
+        return self._dml3_d_effects_rendering_mode
+
+    @dml3_d_effects_rendering_mode.setter
+    def dml3_d_effects_rendering_mode(self, dml3_d_effects_rendering_mode):
+        """Sets the dml3_d_effects_rendering_mode of this DocSaveOptionsData.
+
+        Gets or sets a value determining how 3D effects are rendered.  # noqa: E501
+
+        :param dml3_d_effects_rendering_mode: The dml3_d_effects_rendering_mode of this DocSaveOptionsData.  # noqa: E501
+        :type: str
+        """
+        allowed_values = ["Basic", "Advanced"]  # noqa: E501
+        if not dml3_d_effects_rendering_mode.isdigit():	
+            if dml3_d_effects_rendering_mode not in allowed_values:
+                raise ValueError(
+                    "Invalid value for `dml3_d_effects_rendering_mode` ({0}), must be one of {1}"  # noqa: E501
+                    .format(dml3_d_effects_rendering_mode, allowed_values))
+            self._dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
+        else:
+            self._dml3_d_effects_rendering_mode = allowed_values[int(dml3_d_effects_rendering_mode) if six.PY3 else long(dml3_d_effects_rendering_mode)]
+    @property
+    def update_last_printed_property(self):
+        """Gets the update_last_printed_property of this DocSaveOptionsData.  # noqa: E501
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501
+
+        :return: The update_last_printed_property of this DocSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._update_last_printed_property
+
+    @update_last_printed_property.setter
+    def update_last_printed_property(self, update_last_printed_property):
+        """Sets the update_last_printed_property of this DocSaveOptionsData.
+
+        Gets or sets a value determining whether the Aspose.Words.Properties.BuiltInDocumentProperties.LastPrinted property is updated before saving.  # noqa: E501
+
+        :param update_last_printed_property: The update_last_printed_property of this DocSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._update_last_printed_property = update_last_printed_property
+    @property
     def always_compress_metafiles(self):
         """Gets the always_compress_metafiles of this DocSaveOptionsData.  # noqa: E501
 
