@@ -87,7 +87,7 @@ class DocumentPropertyResponse(object):
     def document_property(self):
         """Gets the document_property of this DocumentPropertyResponse.  # noqa: E501
 
-        Gets or sets document property.  # noqa: E501
+        Gets or sets document_property.  # noqa: E501
 
         :return: The document_property of this DocumentPropertyResponse.  # noqa: E501
         :rtype: DocumentProperty
@@ -98,7 +98,7 @@ class DocumentPropertyResponse(object):
     def document_property(self, document_property):
         """Sets the document_property of this DocumentPropertyResponse.
 
-        Gets or sets document property.  # noqa: E501
+        Gets or sets document_property.  # noqa: E501
 
         :param document_property: The document_property of this DocumentPropertyResponse.  # noqa: E501
         :type: DocumentProperty
