@@ -66,7 +66,7 @@ class FieldCollection(object):
     def link(self):
         """Gets the link of this FieldCollection.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :return: The link of this FieldCollection.  # noqa: E501
         :rtype: WordsApiLink
@@ -77,7 +77,7 @@ class FieldCollection(object):
     def link(self, link):
         """Sets the link of this FieldCollection.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :param link: The link of this FieldCollection.  # noqa: E501
         :type: WordsApiLink
