@@ -41,8 +41,6 @@ class FormFieldCheckbox(object):
                             and the value is json key in definition.
     """
     swagger_types = {
-        'link': 'WordsApiLink',
-        'node_id': 'str',
         'calculate_on_exit': 'bool',
         'enabled': 'bool',
         'entry_macro': 'str',
@@ -52,14 +50,14 @@ class FormFieldCheckbox(object):
         'own_help': 'bool',
         'own_status': 'bool',
         'status_text': 'str',
+        'link': 'WordsApiLink',
+        'node_id': 'str',
         'check_box_size': 'float',
         'checked': 'bool',
         'is_check_box_exact_size': 'bool'
     }
 
     attribute_map = {
-        'link': 'link',
-        'node_id': 'NodeId',
         'calculate_on_exit': 'CalculateOnExit',
         'enabled': 'Enabled',
         'entry_macro': 'EntryMacro',
@@ -69,16 +67,16 @@ class FormFieldCheckbox(object):
         'own_help': 'OwnHelp',
         'own_status': 'OwnStatus',
         'status_text': 'StatusText',
+        'link': 'link',
+        'node_id': 'NodeId',
         'check_box_size': 'CheckBoxSize',
         'checked': 'Checked',
         'is_check_box_exact_size': 'IsCheckBoxExactSize'
     }
 
-    def __init__(self, link=None, node_id=None, calculate_on_exit=None, enabled=None, entry_macro=None, exit_macro=None, help_text=None, name=None, own_help=None, own_status=None, status_text=None, check_box_size=None, checked=None, is_check_box_exact_size=None):  # noqa: E501
+    def __init__(self, calculate_on_exit=None, enabled=None, entry_macro=None, exit_macro=None, help_text=None, name=None, own_help=None, own_status=None, status_text=None, link=None, node_id=None, check_box_size=None, checked=None, is_check_box_exact_size=None):  # noqa: E501
         """FormFieldCheckbox - a model defined in Swagger"""  # noqa: E501
 
-        self._link = None
-        self._node_id = None
         self._calculate_on_exit = None
         self._enabled = None
         self._entry_macro = None
@@ -88,15 +86,13 @@ class FormFieldCheckbox(object):
         self._own_help = None
         self._own_status = None
         self._status_text = None
+        self._link = None
+        self._node_id = None
         self._check_box_size = None
         self._checked = None
         self._is_check_box_exact_size = None
         self.discriminator = None
 
-        if link is not None:
-            self.link = link
-        if node_id is not None:
-            self.node_id = node_id
         if calculate_on_exit is not None:
             self.calculate_on_exit = calculate_on_exit
         if enabled is not None:
@@ -115,6 +111,10 @@ class FormFieldCheckbox(object):
             self.own_status = own_status
         if status_text is not None:
             self.status_text = status_text
+        if link is not None:
+            self.link = link
+        if node_id is not None:
+            self.node_id = node_id
         if check_box_size is not None:
             self.check_box_size = check_box_size
         if checked is not None:
@@ -123,48 +123,6 @@ class FormFieldCheckbox(object):
             self.is_check_box_exact_size = is_check_box_exact_size
 
     @property
-    def link(self):
-        """Gets the link of this FormFieldCheckbox.  # noqa: E501
-
-        Gets or sets link to the document.  # noqa: E501
-
-        :return: The link of this FormFieldCheckbox.  # noqa: E501
-        :rtype: WordsApiLink
-        """
-        return self._link
-
-    @link.setter
-    def link(self, link):
-        """Sets the link of this FormFieldCheckbox.
-
-        Gets or sets link to the document.  # noqa: E501
-
-        :param link: The link of this FormFieldCheckbox.  # noqa: E501
-        :type: WordsApiLink
-        """
-        self._link = link
-    @property
-    def node_id(self):
-        """Gets the node_id of this FormFieldCheckbox.  # noqa: E501
-
-        Gets or sets node id.  # noqa: E501
-
-        :return: The node_id of this FormFieldCheckbox.  # noqa: E501
-        :rtype: str
-        """
-        return self._node_id
-
-    @node_id.setter
-    def node_id(self, node_id):
-        """Sets the node_id of this FormFieldCheckbox.
-
-        Gets or sets node id.  # noqa: E501
-
-        :param node_id: The node_id of this FormFieldCheckbox.  # noqa: E501
-        :type: str
-        """
-        self._node_id = node_id
-    @property
     def calculate_on_exit(self):
         """Gets the calculate_on_exit of this FormFieldCheckbox.  # noqa: E501
 
@@ -354,10 +312,52 @@ class FormFieldCheckbox(object):
         """
         self._status_text = status_text
     @property
+    def link(self):
+        """Gets the link of this FormFieldCheckbox.  # noqa: E501
+
+        Gets or sets link.  # noqa: E501
+
+        :return: The link of this FormFieldCheckbox.  # noqa: E501
+        :rtype: WordsApiLink
+        """
+        return self._link
+
+    @link.setter
+    def link(self, link):
+        """Sets the link of this FormFieldCheckbox.
+
+        Gets or sets link.  # noqa: E501
+
+        :param link: The link of this FormFieldCheckbox.  # noqa: E501
+        :type: WordsApiLink
+        """
+        self._link = link
+    @property
+    def node_id(self):
+        """Gets the node_id of this FormFieldCheckbox.  # noqa: E501
+
+        Gets or sets node id.  # noqa: E501
+
+        :return: The node_id of this FormFieldCheckbox.  # noqa: E501
+        :rtype: str
+        """
+        return self._node_id
+
+    @node_id.setter
+    def node_id(self, node_id):
+        """Sets the node_id of this FormFieldCheckbox.
+
+        Gets or sets node id.  # noqa: E501
+
+        :param node_id: The node_id of this FormFieldCheckbox.  # noqa: E501
+        :type: str
+        """
+        self._node_id = node_id
+    @property
     def check_box_size(self):
         """Gets the check_box_size of this FormFieldCheckbox.  # noqa: E501
 
-        Gets or sets the size of the checkbox in points. Has effect only when  is true.  # noqa: E501
+        Gets or sets the size of the checkbox in points. Has effect only when IsCheckBoxExactSize is true.  # noqa: E501
 
         :return: The check_box_size of this FormFieldCheckbox.  # noqa: E501
         :rtype: float
@@ -368,7 +368,7 @@ class FormFieldCheckbox(object):
     def check_box_size(self, check_box_size):
         """Sets the check_box_size of this FormFieldCheckbox.
 
-        Gets or sets the size of the checkbox in points. Has effect only when  is true.  # noqa: E501
+        Gets or sets the size of the checkbox in points. Has effect only when IsCheckBoxExactSize is true.  # noqa: E501
 
         :param check_box_size: The check_box_size of this FormFieldCheckbox.  # noqa: E501
         :type: float
