@@ -3,10 +3,14 @@ from asposewordscloud.models.requests.update_table_row_format_request import Upd
 from asposewordscloud.models.requests.update_table_properties_without_node_path_request import UpdateTablePropertiesWithoutNodePathRequest
 from asposewordscloud.models.requests.update_table_properties_request import UpdateTablePropertiesRequest
 from asposewordscloud.models.requests.update_table_cell_format_request import UpdateTableCellFormatRequest
+from asposewordscloud.models.requests.update_style_request import UpdateStyleRequest
 from asposewordscloud.models.requests.update_section_page_setup_request import UpdateSectionPageSetupRequest
 from asposewordscloud.models.requests.update_run_font_request import UpdateRunFontRequest
 from asposewordscloud.models.requests.update_run_request import UpdateRunRequest
+from asposewordscloud.models.requests.update_paragraph_list_format_request import UpdateParagraphListFormatRequest
 from asposewordscloud.models.requests.update_paragraph_format_request import UpdateParagraphFormatRequest
+from asposewordscloud.models.requests.update_list_level_request import UpdateListLevelRequest
+from asposewordscloud.models.requests.update_list_request import UpdateListRequest
 from asposewordscloud.models.requests.update_form_field_without_node_path_request import UpdateFormFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.update_form_field_request import UpdateFormFieldRequest
 from asposewordscloud.models.requests.update_footnote_without_node_path_request import UpdateFootnoteWithoutNodePathRequest
@@ -48,9 +52,12 @@ from asposewordscloud.models.requests.insert_table_without_node_path_request imp
 from asposewordscloud.models.requests.insert_table_row_request import InsertTableRowRequest
 from asposewordscloud.models.requests.insert_table_cell_request import InsertTableCellRequest
 from asposewordscloud.models.requests.insert_table_request import InsertTableRequest
+from asposewordscloud.models.requests.insert_style_request import InsertStyleRequest
 from asposewordscloud.models.requests.insert_run_request import InsertRunRequest
 from asposewordscloud.models.requests.insert_paragraph_request import InsertParagraphRequest
 from asposewordscloud.models.requests.insert_page_numbers_request import InsertPageNumbersRequest
+from asposewordscloud.models.requests.insert_or_update_paragraph_tab_stop_request import InsertOrUpdateParagraphTabStopRequest
+from asposewordscloud.models.requests.insert_list_request import InsertListRequest
 from asposewordscloud.models.requests.insert_header_footer_request import InsertHeaderFooterRequest
 from asposewordscloud.models.requests.insert_form_field_without_node_path_request import InsertFormFieldWithoutNodePathRequest
 from asposewordscloud.models.requests.insert_form_field_request import InsertFormFieldRequest
@@ -71,6 +78,9 @@ from asposewordscloud.models.requests.get_table_properties_request import GetTab
 from asposewordscloud.models.requests.get_table_cell_format_request import GetTableCellFormatRequest
 from asposewordscloud.models.requests.get_table_cell_request import GetTableCellRequest
 from asposewordscloud.models.requests.get_table_request import GetTableRequest
+from asposewordscloud.models.requests.get_styles_request import GetStylesRequest
+from asposewordscloud.models.requests.get_style_from_document_element_request import GetStyleFromDocumentElementRequest
+from asposewordscloud.models.requests.get_style_request import GetStyleRequest
 from asposewordscloud.models.requests.get_sections_request import GetSectionsRequest
 from asposewordscloud.models.requests.get_section_page_setup_request import GetSectionPageSetupRequest
 from asposewordscloud.models.requests.get_section_request import GetSectionRequest
@@ -81,6 +91,9 @@ from asposewordscloud.models.requests.get_range_text_request import GetRangeText
 from asposewordscloud.models.requests.get_paragraphs_without_node_path_request import GetParagraphsWithoutNodePathRequest
 from asposewordscloud.models.requests.get_paragraphs_request import GetParagraphsRequest
 from asposewordscloud.models.requests.get_paragraph_without_node_path_request import GetParagraphWithoutNodePathRequest
+from asposewordscloud.models.requests.get_paragraph_tab_stops_request import GetParagraphTabStopsRequest
+from asposewordscloud.models.requests.get_paragraph_list_format_without_node_path_request import GetParagraphListFormatWithoutNodePathRequest
+from asposewordscloud.models.requests.get_paragraph_list_format_request import GetParagraphListFormatRequest
 from asposewordscloud.models.requests.get_paragraph_format_without_node_path_request import GetParagraphFormatWithoutNodePathRequest
 from asposewordscloud.models.requests.get_paragraph_format_request import GetParagraphFormatRequest
 from asposewordscloud.models.requests.get_paragraph_request import GetParagraphRequest
@@ -88,6 +101,8 @@ from asposewordscloud.models.requests.get_office_math_objects_without_node_path_
 from asposewordscloud.models.requests.get_office_math_objects_request import GetOfficeMathObjectsRequest
 from asposewordscloud.models.requests.get_office_math_object_without_node_path_request import GetOfficeMathObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.get_office_math_object_request import GetOfficeMathObjectRequest
+from asposewordscloud.models.requests.get_lists_request import GetListsRequest
+from asposewordscloud.models.requests.get_list_request import GetListRequest
 from asposewordscloud.models.requests.get_header_footers_request import GetHeaderFootersRequest
 from asposewordscloud.models.requests.get_header_footer_of_section_request import GetHeaderFooterOfSectionRequest
 from asposewordscloud.models.requests.get_header_footer_request import GetHeaderFooterRequest
@@ -140,6 +155,8 @@ from asposewordscloud.models.requests.delete_table_request import DeleteTableReq
 from asposewordscloud.models.requests.delete_section_request import DeleteSectionRequest
 from asposewordscloud.models.requests.delete_run_request import DeleteRunRequest
 from asposewordscloud.models.requests.delete_paragraph_without_node_path_request import DeleteParagraphWithoutNodePathRequest
+from asposewordscloud.models.requests.delete_paragraph_tab_stop_request import DeleteParagraphTabStopRequest
+from asposewordscloud.models.requests.delete_paragraph_list_format_request import DeleteParagraphListFormatRequest
 from asposewordscloud.models.requests.delete_paragraph_request import DeleteParagraphRequest
 from asposewordscloud.models.requests.delete_office_math_object_without_node_path_request import DeleteOfficeMathObjectWithoutNodePathRequest
 from asposewordscloud.models.requests.delete_office_math_object_request import DeleteOfficeMathObjectRequest
@@ -162,14 +179,19 @@ from asposewordscloud.models.requests.delete_document_property_request import De
 from asposewordscloud.models.requests.delete_comment_request import DeleteCommentRequest
 from asposewordscloud.models.requests.delete_borders_request import DeleteBordersRequest
 from asposewordscloud.models.requests.delete_border_request import DeleteBorderRequest
+from asposewordscloud.models.requests.delete_all_paragraph_tab_stops_request import DeleteAllParagraphTabStopsRequest
 from asposewordscloud.models.requests.create_or_update_document_property_request import CreateOrUpdateDocumentPropertyRequest
 from asposewordscloud.models.requests.create_folder_request import CreateFolderRequest
 from asposewordscloud.models.requests.create_document_request import CreateDocumentRequest
+from asposewordscloud.models.requests.copy_style_request import CopyStyleRequest
 from asposewordscloud.models.requests.copy_folder_request import CopyFolderRequest
 from asposewordscloud.models.requests.copy_file_request import CopyFileRequest
 from asposewordscloud.models.requests.convert_document_request import ConvertDocumentRequest
 from asposewordscloud.models.requests.compare_document_request import CompareDocumentRequest
 from asposewordscloud.models.requests.classify_document_request import ClassifyDocumentRequest
 from asposewordscloud.models.requests.classify_request import ClassifyRequest
+from asposewordscloud.models.requests.build_report_online_request import BuildReportOnlineRequest
+from asposewordscloud.models.requests.build_report_request import BuildReportRequest
+from asposewordscloud.models.requests.apply_style_to_document_element_request import ApplyStyleToDocumentElementRequest
 from asposewordscloud.models.requests.append_document_request import AppendDocumentRequest
 from asposewordscloud.models.requests.accept_all_revisions_request import AcceptAllRevisionsRequest
