@@ -29,7 +29,7 @@ class SaveAsRangeRequest(object):
     Request model for save_as_range operation.
     Initializes a new instance.
     :param name The document.
-    :param range_start_identifier The range start identifier. Identifier is the value of the \"nodeId\" field, which every document node has, extended with the prefix \"id\". It looks like \"id0.0.7\". Also values like \"image5\" and \"table3\" can be used as an identifier for images and tables, where the number is an index of the image/table.
+    :param range_start_identifier The range start identifier. Identifier is the value of the "nodeId" field, which every document node has, extended with the prefix "id". It looks like "id0.0.7". Also values like "image5" and "table3" can be used as an identifier for images and tables, where the number is an index of the image/table.
     :param document_parameters Parameters of a new document.
     :param range_end_identifier The range end identifier.
     :param folder Original document folder.
@@ -38,7 +38,7 @@ class SaveAsRangeRequest(object):
     :param password Password for opening an encrypted document.
     """
 
-    def __init__(self, name, range_start_identifier, document_parameters, range_end_identifier, folder=None, storage=None, load_encoding=None, password=None):
+    def __init__(self, name, range_start_identifier, document_parameters, range_end_identifier=None, folder=None, storage=None, load_encoding=None, password=None):
         self.name = name
         self.range_start_identifier = range_start_identifier
         self.document_parameters = document_parameters
