@@ -81,7 +81,7 @@ class TableRowFormat(object):
     def link(self):
         """Gets the link of this TableRowFormat.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :return: The link of this TableRowFormat.  # noqa: E501
         :rtype: WordsApiLink
@@ -92,7 +92,7 @@ class TableRowFormat(object):
     def link(self, link):
         """Sets the link of this TableRowFormat.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets link.  # noqa: E501
 
         :param link: The link of this TableRowFormat.  # noqa: E501
         :type: WordsApiLink
