@@ -32,6 +32,8 @@ from test.base_test_context import BaseTestContext
 
 class TestParagraphs(BaseTestContext):
     test_folder = 'DocumentElements/Paragraphs'
+    test_list_folder = 'DocumentElements/ParagraphListFormat'
+    test_tab_stop_folder = 'DocumentElements/Paragraphs'
 
     #
     # Test for removing paragraph
@@ -301,3 +303,103 @@ class TestParagraphs(BaseTestContext):
                                                                                           self.test_folder))
         result = self.words_api.update_paragraph_format(request)
         self.assertIsNotNone(result, 'Error has occurred while update section page setup')
+
+    #
+    # Test for getting paragraph list format
+    #
+    def test_get_paragraph_list_format(self):
+        filename = 'ParagraphGetListFormat.doc'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_list_folder, filename), open(os.path.join(self.local_test_folder, self.test_list_folder, filename), 'rb'))
+        request = asposewordscloud.models.requests.GetParagraphListFormatRequest(filename, '', index, os.path.join(self.remote_test_folder,self.test_list_folder))
+        result = self.words_api.get_paragraph_list_format(request)
+        self.assertIsNotNone(result, 'Error has occurred while get document paragraph')
+
+    #
+    # Test for getting paragraph list format without node path
+    #
+    def test_get_paragraph_list_format_without_node_path(self):
+        filename = 'ParagraphGetListFormat.doc'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_list_folder, filename), open(os.path.join(self.local_test_folder, self.test_list_folder, filename), 'rb'))
+        request = asposewordscloud.models.requests.GetParagraphListFormatWithoutNodePathRequest(filename, index, os.path.join(self.remote_test_folder,self.test_list_folder))
+        result = self.words_api.get_paragraph_list_format_without_node_path(request)
+        self.assertIsNotNone(result, 'Error has occurred while get document paragraph')
+
+    #
+    # Test for updating paragraph list format
+    #
+    def test_update_paragraph_list_format(self):
+        filename = 'ParagraphUpdateListFormat.doc'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_list_folder, filename), open(os.path.join(self.local_test_folder, self.test_list_folder, filename), 'rb'))
+        dto = asposewordscloud.models.ListFormatUpdate()
+        dto.list_id = 2
+
+        request = asposewordscloud.models.requests.UpdateParagraphListFormatRequest(filename, dto, '', index, os.path.join(self.remote_test_folder,self.test_list_folder))
+        result = self.words_api.update_paragraph_list_format(request)
+        self.assertIsNotNone(result, 'Error has occurred while get document paragraph')
+
+    #
+    # Test for deleting paragraph list format
+    #
+    def test_delete_paragraph_list_format(self):
+        filename = 'ParagraphDeleteListFormat.doc'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_list_folder, filename), open(os.path.join(self.local_test_folder, self.test_list_folder, filename), 'rb'))
+        request = asposewordscloud.models.requests.DeleteParagraphListFormatRequest(filename, '', index, os.path.join(self.remote_test_folder,self.test_list_folder))
+        result = self.words_api.delete_paragraph_list_format(request)
+        self.assertIsNotNone(result, 'Error has occurred while get document paragraph')
+
+    #
+    # Test for getting paragraph tab stops
+    #
+    def test_get_paragraph_tab_stops(self):
+        filename = 'ParagraphTabStops.docx'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_tab_stop_folder, filename), open(os.path.join(self.local_test_folder, self.test_tab_stop_folder, filename), 'rb'))
+        request = asposewordscloud.models.requests.GetParagraphTabStopsRequest(filename, '', index, os.path.join(self.remote_test_folder,self.test_tab_stop_folder))
+        result = self.words_api.get_paragraph_tab_stops(request)
+        self.assertIsNotNone(result, 'Error has occurred while getting document paragraph tab stops')
+
+    #
+    # Test for inserting paragraph tab stops
+    #
+    def test_insert_or_update_paragraph_tab_stop(self):
+        filename = 'ParagraphTabStops.docx'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_tab_stop_folder, filename), open(os.path.join(self.local_test_folder, self.test_tab_stop_folder, filename), 'rb'))
+        dto = asposewordscloud.models.TabStopInsert("Left", "None", 72)
+        request = asposewordscloud.models.requests.InsertOrUpdateParagraphTabStopRequest(filename, '', dto, index, os.path.join(self.remote_test_folder,self.test_tab_stop_folder))
+        result = self.words_api.insert_or_update_paragraph_tab_stop(request)
+        self.assertIsNotNone(result, 'Error has occurred while updating document paragraph tab stops')
+
+    #
+    # Test for deleting all paragraph tab stops
+    #
+    def test_delete_all_paragraph_tab_stops(self):
+        filename = 'ParagraphTabStops.docx'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_tab_stop_folder, filename), open(os.path.join(self.local_test_folder, self.test_tab_stop_folder, filename), 'rb'))
+        request = asposewordscloud.models.requests.DeleteAllParagraphTabStopsRequest(filename, '', index, os.path.join(self.remote_test_folder,self.test_tab_stop_folder))
+        result = self.words_api.delete_all_paragraph_tab_stops(request)
+        self.assertIsNotNone(result, 'Error has occurred while deleting document paragraph tab stops')       
+
+    #
+    # Test for deleting a paragraph tab stop
+    #
+    def test_delete_paragraph_tab_stop(self):
+        filename = 'ParagraphTabStops.docx'
+        index = 0
+
+        self.upload_file(os.path.join(self.remote_test_folder, self.test_tab_stop_folder, filename), open(os.path.join(self.local_test_folder, self.test_tab_stop_folder, filename), 'rb'))
+        request = asposewordscloud.models.requests.DeleteParagraphTabStopRequest(filename, '', 72, index, os.path.join(self.remote_test_folder,self.test_tab_stop_folder))
+        result = self.words_api.delete_paragraph_tab_stop(request)
+        self.assertIsNotNone(result, 'Error has occurred while deleting document paragraph tab stops') 
\ No newline at end of file
